@@ -34,11 +34,15 @@ class Database:
 
             
             if price_adj == False:
-                ohlc_result = json.loads(json.loads(response.content).replace("'", "\""))
+
+                ohlc_result = json.loads(json.loads(response.content).replace("'", "\"").replace('False','0').replace('True','1'))
             else:
-                result = ast.literal_eval(json.loads(response.content))
+
+                #result = ast.literal_eval(json.loads(response.content))
+                result = json.loads(json.loads(response.content).replace("'", "\"").replace('[(', '\"[(').replace(')]',')]\"').replace('False','0').replace('True','1'))
                 ohlc_result = result[0]
-                qfq_result = result[1]
+                qfq_result = result[1].replace('[','').replace(']','').replace(' ','')
+                qfq_result = ast.literal_eval(qfq_result)
                 qfq_df = pd.DataFrame(qfq_result, columns=['date', 'qfq_factor'])
 
             df_list = []
@@ -59,16 +63,19 @@ class Database:
                 df['datetime'] = pd.to_datetime(df['datetime'], format='%Y%m%d %H%M%S')
                 cols = ['datetime', 'date', 'time', 'open', 'high', 'low', 'close', 'volume']
 
-            else:
+            elif freq == '1D':
                 df['datetime'] = df['date']
+
                 df['datetime'] = pd.to_datetime(df['datetime'], format='%Y%m%d')
-                cols = ['datetime', 'date', 'open', 'high', 'low', 'close', 'volume']
+                cols = ['datetime','date','open','high','low','close','volume','susp','auc_close','adj_close','gross_volume','turnover','VWAP']
+                df['susp'] = df['susp'].astype(bool)
 
             df = df[cols]
 
             df = df.set_index(keys='datetime')
             df = df.sort_index()
 
+
             if price_adj == True:
                 qfq_df = qfq_df[qfq_df['date'] > 20100000]
                 qfq_df = qfq_df.iloc[::-1].reset_index(drop=True)
@@ -97,7 +104,7 @@ class Database:
                 if vol_adj == True:
                     col_list = ['open', 'high', 'low', 'close']
                 else:
-                    col_list = ['open', 'high', 'low', 'close', 'volume']
+                    col_list = ['open', 'high', 'low', 'close', 'volume','gross_volume']
 
                 for col in col_list:
                     df[col] = df[col] * df['qfq_factor']
@@ -110,7 +117,7 @@ class Database:
                 if 'T' in freq:
                     df = df[['date', 'time', 'open', 'high', 'low', 'close', 'volume']]
                 else:
-                    df = df[['date', 'open', 'high', 'low', 'close', 'volume']]
+                    df = df[['date','open','high','low','close','volume','susp','auc_close','adj_close','gross_volume','turnover','VWAP']]
 
             return df
     
